% Auto-generated chapter 29 for ibnmajah
% Hadiths in this chapter: 120

\hadithdefcmd{ibnmajah}{3251}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عَوْفٍ، عَنْ زُرَارَةَ بْنِ أَوْفَى، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ سَلاَمٍ، قَالَ لَمَّا قَدِمَ النَّبِيُّ ـ صلى الله عليه وسلم ـ الْمَدِينَةَ انْجَفَلَ النَّاسُ قِبَلَهُ وَقِيلَ قَدْ قَدِمَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ قَدْ قَدِمَ رَسُولُ اللَّهِ قَدْ قَدِمَ رَسُولُ اللَّهِ ‏.‏ ثَلاَثًا فَجِئْتُ فِي النَّاسِ لأَنْظُرَ فَلَمَّا تَبَيَّنْتُ وَجْهَهُ عَرَفْتُ أَنَّ وَجْهَهُ لَيْسَ بِوَجْهِ كَذَّابٍ فَكَانَ أَوَّلَ شَىْءٍ سَمِعْتُهُ تَكَلَّمَ بِهِ أَنْ قَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ أَفْشُوا السَّلاَمَ وَأَطْعِمُوا الطَّعَامَ وَصِلُوا الأَرْحَامَ وَصَلُّوا بِاللَّيْلِ وَالنَّاسُ نِيَامٌ تَدْخُلُوا الْجَنَّةَ بِسَلاَمٍ ‏"‏ ‏.‏\hadithno{3251}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{‘Abdullah bin Salam said:“When the Prophet (ﷺ) came to Al-Madinah, the people rushed to meet him, and it was said: ‘The Messenger of Allah (ﷺ) has come! The Messenger of Allah (ﷺ) has come! The Messenger of Allah (ﷺ) has come!’ Three times. I came with the people to see him, and when I saw his face clearly, I knew that his face was not the face of a liar. The first thing I heard him say was when he said: ‘O people! Spread (the greeting of) Salam, feed others, uphold the ties of kinship, and pray during the night when people are sleeping, and you will enter Paradise with Salam.”}}
\hadithdefcmd{ibnmajah}{3252}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى الأَزْدِيُّ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ سُلَيْمَانُ بْنُ مُوسَى حُدِّثْنَا عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أَفْشُوا السَّلاَمَ وَأَطْعِمُوا الطَّعَامَ وَكُونُوا إِخْوَانًا كَمَا أَمَرَكُمُ اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{3252}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘Abdullah bin ‘Umar used to say that the Messenger of Allah (ﷺ) said:“Spread (the greeting og) Salam, offer food (to the needy), and be brothers as Allah, the Mighty and Sublime, has honored you.”}}
\hadithdefcmd{ibnmajah}{3253}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، ‏.‏ أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ يَا رَسُولَ اللَّهِ أَىُّ الإِسْلاَمِ خَيْرٌ قَالَ ‏ "‏ تُطْعِمُ الطَّعَامَ وَتَقْرَأُ السَّلاَمَ عَلَى مَنْ عَرَفْتَ وَمَنْ لَمْ تَعْرِفْ ‏"‏ ‏.‏\hadithno{3253}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Abdullah bin ‘Amr that a man asked the Messenger of Allah (ﷺ):“O Messenger of Allah, which (aspect) of Islam is the best?” He said: “Offering food (to the needy) and greeting with Salam those whom you know and those whom you do not know.”}}
\hadithdefcmd{ibnmajah}{3254}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الرَّقِّيُّ، حَدَّثَنَا يَحْيَى بْنُ زِيَادٍ الأَسَدِيُّ، أَنْبَأَنَا ابْنُ جُرَيْجٍ، أَنْبَأَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ طَعَامُ الْوَاحِدِ يَكْفِي الاِثْنَيْنِ وَطَعَامُ الاِثْنَيْنِ يَكْفِي الأَرْبَعَةَ وَطَعَامُ الأَرْبَعَةِ يَكْفِي الثَّمَانِيَةَ ‏"‏ ‏.‏\hadithno{3254}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that the Messenger of Allah (ﷺ) said:“The food of one person is sufficient for two, the food of two is sufficient for four, and the food for four is sufficient for eight.”}}
\hadithdefcmd{ibnmajah}{3255}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، حَدَّثَنَا سَعِيدُ بْنُ زَيْدٍ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، قَهْرَمَانُ آلِ الزُّبَيْرِ قَالَ سَمِعْتُ سَالِمَ بْنَ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عُمَرَ بْنِ الْخَطَّابِ قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ طَعَامَ الْوَاحِدِ يَكْفِي الاِثْنَيْنِ وَإِنَّ طَعَامَ الاِثْنَيْنِ يَكْفِي الثَّلاَثَةَ وَالأَرْبَعَةَ وَإِنَّ طَعَامَ الأَرْبَعَةِ يَكْفِي الْخَمْسَةَ وَالسِّتَّةَ ‏"‏ ‏.‏\hadithno{3255}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Umar bin Khattab that the Messenger of Allah (ﷺ) said:“The food of one is sufficient for two, and the food of two is sufficient for three or four, and the food of four is sufficient for five or six.’”}}
\hadithdefcmd{ibnmajah}{3256}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْمُؤْمِنُ يَأْكُلُ فِي مِعًى وَاحِدٍ وَالْكَافِرُ يَأْكُلُ فِي سَبْعَةِ أَمْعَاءٍ ‏"‏ ‏.‏\hadithno{3256}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The believer eats with one intestine and the disbeliever eats with seven intestines.’”}}
\hadithdefcmd{ibnmajah}{3257}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الْكَافِرُ يَأْكُلُ فِي سَبْعَةِ أَمْعَاءٍ وَالْمُؤْمِنُ يَأْكُلُ فِي مِعًى وَاحِدٍ ‏"‏ ‏.‏\hadithno{3257}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn ‘Umar that the Prophet (ﷺ) said:“The disbeliever eats with seven intestines and the believer eats with one intestine.”}}
\hadithdefcmd{ibnmajah}{3258}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ، عَنْ جَدِّهِ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْمُؤْمِنُ يَأْكُلُ فِي مِعًى وَاحِدٍ وَالْكَافِرُ يَأْكُلُ فِي سَبْعَةِ أَمْعَاءٍ ‏"‏ ‏.‏\hadithno{3258}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Musa that the Messenger of Allah (ﷺ) said:“The believer eats with one intestine and the disbeliever eats with seven intestines.”}}
\hadithdefcmd{ibnmajah}{3259}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ مَا عَابَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ طَعَامًا قَطُّ إِنْ رَضِيَهُ أَكَلَهُ وَإِلاَّ تَرَكَهُ ‏.‏ حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي يَحْيَى، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ مِثْلَهُ ‏.‏ قَالَ أَبُو بَكْرٍ نُخَالِفُ فِيهِ يَقُولُونَ عَنْ أَبِي حَازِمٍ ‏.‏\hadithno{3259}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hazim that Abu Hurairah said:“The Messenger of Allah (ﷺ) never criticized any food. If it pleased him, he would eat it and if it did not he would leave it.” Another chain reports the same}}
\hadithdefcmd{ibnmajah}{3260}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا كَثِيرُ بْنُ سُلَيْمٍ، سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَحَبَّ أَنْ يُكْثِرَ اللَّهُ خَيْرَ بَيْتِهِ فَلْيَتَوَضَّأْ إِذَا حَضَرَ غَدَاؤُهُ وَإِذَا رُفِعَ ‏"‏ ‏.‏\hadithno{3260}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Kathir bin Sulaim narrated that he heard Anas bin Malik say:“The Messenger of Allah (ﷺ) said: ‘Whoever would like Allah to increase the goodness of his house, should perform ablution (wash hands) when his breakfast is brought to him and when it is taken away.’”}}
\hadithdefcmd{ibnmajah}{3261}{حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ، حَدَّثَنَا صَاعِدُ بْنُ عُبَيْدٍ الْجَزَرِيُّ، حَدَّثَنَا زُهَيْرُ بْنُ مُعَاوِيَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ جُحَادَةَ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ الْمَكِّيُّ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ خَرَجَ مِنَ الْغَائِطِ فَأُتِيَ بِطَعَامٍ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَلاَ آتِيكَ بِوَضُوءٍ قَالَ ‏ "‏ أُرِيدُ الصَّلاَةَ ‏"‏ ‏.‏\hadithno{3261}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) went out to toilet, then food was brought. A man said:“O Messenger of Allah, are you not going to perform ablution?” He said: ‘Am I going to pray?’}}
\hadithdefcmd{ibnmajah}{3262}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ مِسْعَرٍ، عَنْ عَلِيِّ بْنِ الأَقْمَرِ، عَنْ أَبِي جُحَيْفَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ آكُلُ مُتَّكِئًا ‏"‏ ‏.‏\hadithno{3262}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Juhaifah that the Messenger of Allah (ﷺ) said:“I do not eat while reclining.”}}
\hadithdefcmd{ibnmajah}{3263}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، حَدَّثَنَا أَبِي، أَنْبَأَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عِرْقٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُسْرٍ، قَالَ أَهْدَيْتُ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ شَاةً فَجَثَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَلَى رُكْبَتَيْهِ يَأْكُلُ فَقَالَ أَعْرَابِيٌّ مَا هَذِهِ الْجِلْسَةُ فَقَالَ ‏ "‏ إِنَّ اللَّهَ جَعَلَنِي عَبْدًا كَرِيمًا وَلَمْ يَجْعَلْنِي جَبَّارًا عَنِيدًا ‏"‏ ‏.‏\hadithno{3263}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘Abdullah bin Busr said:“I gave the Prophet (ﷺ) a gift of a sheep, and the Messenger of Allah (ﷺ) sat on his knees to eat. A Bedouin said: ‘What is this sitting?’ He said: ‘Allah has made me a humble and generous slave (of Allah) and has not made me arrogant and stubborn.’”}}
\hadithdefcmd{ibnmajah}{3264}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنِ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ بُدَيْلِ بْنِ مَيْسَرَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَأْكُلُ طَعَامًا فِي سِتَّةِ نَفَرٍ مِنْ أَصْحَابِهِ فَجَاءَ أَعْرَابِيٌّ فَأَكَلَهُ بِلُقْمَتَيْنِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَمَا أَنَّهُ لَوْ كَانَ قَالَ بِسْمِ اللَّهِ لَكَفَاكُمْ فَإِذَا أَكَلَ أَحَدُكُمْ طَعَامًا فَلْيَقُلْ بِسْمِ اللَّهِ فَإِنْ نَسِيَ أَنْ يَقُولَ بِسْمِ اللَّهِ فِي أَوَّلِهِ فَلْيَقُلْ بِسْمِ اللَّهِ فِي أَوَّلِهِ وَآخِرِهِ ‏"‏ ‏.‏\hadithno{3264}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) was eating food with six of his Companions when a Bedouin came and ate it all in two bites. The Messenger of Allah (ﷺ) said: ‘If he had said Bismillah, it would have sufficed you (all). When any one of you eats food, let him say Bismillah, and if he forgets to say Bismillah at the beginning, let him say Bismillah fi awwalihi wa akhirih (In the Name of Allah at the beginning and at the end).’”}}
\hadithdefcmd{ibnmajah}{3265}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، قَالَ قَالَ لِيَ النَّبِيُّ ـ صلى الله عليه وسلم ـ وَأَنَا آكُلُ ‏ "‏ سَمِّ اللَّهَ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{3265}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Umar bin Abu Salamah said:“The Prophet (ﷺ) said to me, when I was eating: ‘Say the Name of Allah, the Glorified and Exalted.’”}}
\hadithdefcmd{ibnmajah}{3266}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْهِقْلُ بْنُ زِيَادٍ، حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لِيَأْكُلْ أَحَدُكُمْ بِيَمِينِهِ وَلْيَشْرَبْ بِيَمِينِهِ وَلْيَأْخُذْ بِيَمِينِهِ وَلْيُعْطِ بِيَمِينِهِ فَإِنَّ الشَّيْطَانَ يَأْكُلُ بِشِمَالِهِ وَيَشْرَبُ بِشِمَالِهِ وَيُعْطِي بِشِمَالِهِ وَيَأْخُذُ بِشِمَالِهِ ‏"‏ ‏.‏\hadithno{3266}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“Let one of you eat with his right hand and drink with his right hand, and take with his right hand and give with his right hand, for Satan eats with his left hand, drinks with his left hand, gives with his left hand and takes with his left hand.”}}
\hadithdefcmd{ibnmajah}{3267}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الْوَلِيدِ بْنِ كَثِيرٍ، عَنْ وَهْبِ بْنِ كَيْسَانَ، سَمِعَهُ مِنْ، عُمَرَ بْنِ أَبِي سَلَمَةَ قَالَ كُنْتُ غُلاَمًا فِي حِجْرِ النَّبِيِّ ـ صلى الله عليه وسلم ـ وَكَانَتْ يَدِي تَطِيشُ فِي الصَّحْفَةِ فَقَالَ لِي ‏ "‏ يَا غُلاَمُ سَمِّ اللَّهَ وَكُلْ بِيَمِينِكَ وَكُلْ مِمَّا يَلِيكَ ‏"‏ ‏.‏\hadithno{3267}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Wahb bin Kaisan that he heard ‘Umar bin Abu Salamah say:“I was a boy in the care of the Prophet (ﷺ) and my hand used to wander all over the plate. He said to me: ‘O boy! Say the Name of Allah, eat with your right hand, and eat from what is in front of you.’”}}
\hadithdefcmd{ibnmajah}{3268}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تَأْكُلُوا بِالشِّمَالِ فَإِنَّ الشَّيْطَانَ يَأْكُلُ بِالشِّمَالِ ‏"‏ ‏.‏\hadithno{3268}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ) said:“Do not eat with your left hand, for Satan eats with his left hand.”}}
\hadithdefcmd{ibnmajah}{3269}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْعَدَنِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ إِذَا أَكَلَ أَحَدُكُمْ طَعَامًا فَلاَ يَمْسَحْ يَدَهُ حَتَّى يَلْعَقَهَا أَوْ يُلْعِقَهَا ‏"‏ ‏.‏ قَالَ سُفْيَانُ سَمِعْتُ عُمَرَ بْنَ قَيْسٍ، يَسْأَلُ عَمْرَو بْنَ دِينَارٍ أَرَأَيْتَ حَدِيثَ عَطَاءٍ ‏"‏ لاَ يَمْسَحْ أَحَدُكُمْ يَدَهُ حَتَّى يَلْعَقَهَا أَوْ يُلْعِقَهَا ‏"‏ ‏.‏ عَمَّنْ هُوَ قَالَ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ فَإِنَّهُ حُدِّثْنَاهُ عَنْ جَابِرٍ ‏.‏ قَالَ حَفِظْنَاهُ مِنْ عَطَاءٍ عَنِ ابْنِ عَبَّاسٍ قَبْلَ أَنْ يَقْدَمَ جَابِرٌ عَلَيْنَا وَإِنَّمَا لَقِيَ عَطَاءٌ جَابِرًا فِي سَنَةٍ جَاوَرَ فِيهَا بِمَكَّةَ ‏.‏\hadithno{3269}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) said:“When one of you eats food, let him not wipe his hand until he has licked it or has someone else to lick it.”}}
\hadithdefcmd{ibnmajah}{3270}{حَدَّثَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ، أَنْبَأَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، عَنْ سُفْيَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَمْسَحْ أَحَدُكُمْ يَدَهُ حَتَّى يَلْعَقَهَا فَإِنَّهُ لاَ يَدْرِي فِي أَىِّ طَعَامِهِ الْبَرَكَةُ ‏"‏ ‏.‏\hadithno{3270}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ) said:“None of you should wipe his hand until he has licked it, for he does not know where the blessing if in his food.’”}}
\hadithdefcmd{ibnmajah}{3271}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا أَبُو الْيَمَانِ الْبَرَّاءُ، قَالَ حَدَّثَتْنِي جَدَّتِي أَمُّ عَاصِمٍ، قَالَتْ دَخَلَ عَلَيْنَا نُبَيْشَةُ مَوْلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَنَحْنُ نَأْكُلُ فِي قَصْعَةٍ فَقَالَ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَكَلَ فِي قَصْعَةٍ فَلَحِسَهَا اسْتَغْفَرَتْ لَهُ الْقَصْعَةُ ‏"‏ ‏.‏\hadithno{3271}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Umm ‘Asim said:“Nubaishah, the freed slave of the Messenger of Allah (ﷺ), entered upon us when we were eating from a bowl. He said that the Messenger of Allah (ﷺ) said: “Whoever eats from a bowl and cleans it, the bowl will pray for forgiveness for him.”}}
\hadithdefcmd{ibnmajah}{3272}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ وَنَصْرُ بْنُ عَلِيٍّ قَالاَ حَدَّثَنَا الْمُعَلَّى بْنُ رَاشِدٍ أَبُو الْيَمَانِ، حَدَّثَتْنِي جَدَّتِي، عَنْ رَجُلٍ، مِنْ هُذَيْلٍ يُقَالُ لَهُ نُبَيْشَةُ الْخَيْرِ قَالَتْ دَخَلَ عَلَيْنَا نُبَيْشَةُ وَنَحْنُ نَأْكُلُ فِي قَصْعَةٍ لَنَا فَقَالَ حَدَّثَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ أَكَلَ فِي قَصْعَةٍ ثُمَّ لَحِسَهَا اسْتَغْفَرَتْ لَهُ الْقَصْعَةُ ‏"‏ ‏.‏\hadithno{3272}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Mu’alla bin Rashid Abu Yaman said:“My grandmother narrated to me from a man of Hudhail who was called Nubaishah Al-Khair. She said: ‘Nubaishah entered upon us when we were eating from a bowl of ours. He said: “The Messenger of Allah (ﷺ) said: ‘Whoever eats from a bowl then cleans it, the bowl will pray for forgiveness for him.’”}}
\hadithdefcmd{ibnmajah}{3273}{حَدَّثَنَا مُحَمَّدُ بْنُ خَلَفٍ الْعَسْقَلاَنِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا وُضِعَتِ الْمَائِدَةُ فَلْيَأْكُلْ مِمَّا يَلِيهِ وَلاَ يَتَنَاوَلْ مِنْ بَيْنِ يَدَىْ جَلِيسِهِ ‏"‏ ‏.‏\hadithno{3273}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:“When food is served, eat from that which is in front of you, and do not take from what is in front of your companion.’”}}
\hadithdefcmd{ibnmajah}{3274}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا الْعَلاَءُ بْنُ الْفَضْلِ بْنِ عَبْدِ الْمَلِكِ بْنِ أَبِي السَّوِيَّةِ، حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عِكْرَاشٍ، عَنْ أَبِيهِ، عِكْرَاشِ بْنِ ذُؤَيْبٍ قَالَ أُتِيَ النَّبِيُّ ـ صلى الله عليه وسلم ـ بِجَفْنَةٍ كَثِيرَةِ الثَّرِيدِ وَالْوَدَكِ فَأَقْبَلْنَا نَأْكُلُ مِنْهَا فَخَبَطْتُ يَدِي فِي نَوَاحِيهَا فَقَالَ ‏"‏ يَا عِكْرَاشُ كُلْ مِنْ مَوْضِعٍ وَاحِدٍ فَإِنَّهُ طَعَامٌ وَاحِدٌ ‏"‏ ‏.‏ ثُمَّ أُتِينَا بِطَبَقٍ فِيهِ أَلْوَانٌ مِنَ الرُّطَبِ فَجَالَتْ يَدُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي الطَّبَقِ وَقَالَ ‏"‏ يَا عِكْرَاشُ كُلْ مِنْ حَيْثُ شِئْتَ فَإِنَّهُ غَيْرُ لَوْنٍ وَاحِدٍ ‏"‏ ‏.‏\hadithno{3274}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ikrash bin Dhu’aib said:“The Prophet (ﷺ) was brought a bowl filled with Tharid and fatty meat, and we started to eat from it. My hand was wandering all over, so he said: ‘O ‘Ikrash, eat from one spot, for it is all the same food.’ Then we were brought a plate on which were different kinds of fresh dates, and he hand of the Messenger of Allah (ﷺ) went all around the plate. He said: ‘O ‘Ikrash, eat from wherever you want, for they are not all the same.’”}}
\hadithdefcmd{ibnmajah}{3275}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عِرْقٍ الْيَحْصُبِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُسْرٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أُتِيَ بِقَصْعَةٍ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ كُلُوا مِنْ جَوَانِبِهَا وَدَعُوا ذُرْوَتَهَا يُبَارَكْ فِيهَا ‏"‏ ‏.‏\hadithno{3275}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘Abdullah bin Busr narrated that the Messenger of Allah (ﷺ) was brought a bowl (of food). The Messenger of Allah (ﷺ) said:“Eat from the sides and leave the top, so that it may be blessed.”}}
\hadithdefcmd{ibnmajah}{3276}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا أَبُو حَفْصٍ، عُمَرُ بْنُ الدَّرَفْسِ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ أَبِي قَسِيمَةَ، عَنْ وَاثِلَةَ بْنِ الأَسْقَعِ اللَّيْثِيِّ، قَالَ أَخَذَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِرَأْسِ الثَّرِيدِ فَقَالَ ‏ "‏ كُلُوا بِسْمِ اللَّهِ مِنْ حَوَالَيْهَا وَاعْفُوا رَأْسَهَا فَإِنَّ الْبَرَكَةَ تَأْتِيهَا مِنْ فَوْقِهَا ‏"‏ ‏.‏\hadithno{3276}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Wathilah bin Asqa’ Al-Laithi said:“The Messenger of Allah (ﷺ) took hold of the top of the Tharid and said: ‘Eat in the Name of Allah from its sides and leave the top, for the blessing comes from its top.’”}}
\hadithdefcmd{ibnmajah}{3277}{حَدَّثَنَا عَلِيُّ بْنُ الْمُنْذِرِ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا عَطَاءُ بْنُ السَّائِبِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا وُضِعَ الطَّعَامُ فَخُذُوا مِنْ حَافَتِهِ وَذَرُوا وَسَطَهُ فَإِنَّ الْبَرَكَةَ تَنْزِلُ فِي وَسَطِهِ ‏"‏ ‏.‏\hadithno{3277}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“When food is served, take from the sides and leave the middle, for the blessing descends in the middle.”}}
\hadithdefcmd{ibnmajah}{3278}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنْ مَعْقِلِ بْنِ يَسَارٍ، قَالَ بَيْنَمَا هُوَ يَتَغَدَّى إِذْ سَقَطَتْ مِنْهُ لُقْمَةٌ فَتَنَاوَلَهَا فَأَمَاطَ مَا كَانَ فِيهَا مِنْ أَذًى فَأَكَلَهَا فَتَغَامَزَ بِهِ الدَّهَاقِينُ فَقِيلَ أَصْلَحَ اللَّهُ الأَمِيرَ إِنَّ هَؤُلاَءِ الدَّهَاقِينَ يَتَغَامَزُونَ مِنْ أَخْذِكَ اللُّقْمَةَ وَبَيْنَ يَدَيْكَ هَذَا الطَّعَامُ ‏.‏ قَالَ إِنِّي لَمْ أَكُنْ لأَدَعَ مَا سَمِعْتُ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ لِهَذِهِ الأَعَاجِمِ إِنَّا كُنَّا نَأْمُرُ أَحَدَنَا إِذَا سَقَطَتْ لُقْمَتُهُ أَنْ يَأْخُذَهَا فَيُمِيطَ مَا كَانَ فِيهَا مِنْ أَذًى وَيَأْكُلَهَا وَلاَ يَدَعَهَا لِلشَّيْطَانِ ‏.‏\hadithno{3278}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hasan about Ma’qil bin Yasar:“While (he) was eating lunch, a morsel of food fell on the floor. He picked it up, removed whatever dirt had gotten onto it, and ate it. The villagers and farmers winked at one another (finding it odd) and it was said: ‘May Allah help the chief! These villagers and farmers are winking at one another because you picked up a morsel (from the ground) when you have this food in front of you.’ He said: ‘I am not going to give up something I heard from the Messenger of Allah (ﷺ) for these non- Arabs. We were told, if one of us dropped a morsel of food, to pick it up, remove whatever dirt was on it, and eat it, and not to leave it for Satan.’”}}
\hadithdefcmd{ibnmajah}{3279}{حَدَّثَنَا عَلِيُّ بْنُ الْمُنْذِرِ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا وَقَعَتِ اللُّقْمَةُ مِنْ يَدِ أَحَدِكُمْ فَلْيَمْسَحْ مَا عَلَيْهَا مِنَ الأَذَى وَلْيَأْكُلْهَا ‏"‏ ‏.‏\hadithno{3279}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ) said:“If a morsel falls from the hand of anyone of you, let him wipe off whatever dirt that is on it and eat it.”}}
\hadithdefcmd{ibnmajah}{3280}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ مُرَّةَ الْهَمْدَانِيِّ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ كَمَلَ مِنَ الرِّجَالِ كَثِيرٌ وَلَمْ يَكْمُلْ مِنَ النِّسَاءِ إِلاَّ مَرْيَمُ بِنْتُ عِمْرَانَ وَآسِيَةُ امْرَأَةُ فِرْعَوْنَ وَإِنَّ فَضْلَ عَائِشَةَ عَلَى النِّسَاءِ كَفَضْلِ الثَّرِيدِ عَلَى سَائِرِ الطَّعَامِ ‏"‏ ‏.‏\hadithno{3280}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Musa Al-Ash’ari that the Prophet (ﷺ) said:“Many men have attained perfection but no women have attained perfection except Maryam bint ‘Imran (Mary) and Asiyah the wife of Fir’awn. And the superiority of ‘Aishah over other women is like the superiority of Tharid over all other foods.”}}
\hadithdefcmd{ibnmajah}{3281}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَنْبَأَنَا مُسْلِمُ بْنُ خَالِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ فَضْلُ عَائِشَةَ عَلَى النِّسَاءِ كَفَضْلِ الثَّرِيدِ عَلَى سَائِرِ الطَّعَامِ ‏"‏ ‏.‏\hadithno{3281}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Abdullah bin ‘Abdur-Rahman that he heard Anas bin Malik say:“The Messenger of Allah (ﷺ) said: ‘The superiority of ‘Aishah over other women is like the superiority of Tharid over all other foods.’”}}
\hadithdefcmd{ibnmajah}{3282}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ الْمِصْرِيُّ أَبُو الْحَارِثِ الْمُرَادِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ مُحَمَّدِ بْنِ أَبِي يَحْيَى، عَنْ أَبِيهِ، عَنْ سَعِيدِ بْنِ الْحَارِثِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا زَمَانَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَقَلِيلٌ مَا نَجِدُ الطَّعَامَ فَإِذَا نَحْنُ وَجَدْنَاهُ لَمْ يَكُنْ لَنَا مَنَادِيلُ إِلاَّ أَكُفَّنَا وَسَوَاعِدَنَا وَأَقْدَامَنَا ثُمَّ نُصَلِّي وَلاَ نَتَوَضَّأْ ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ غَرِيبٌ لَيْسَ إِلاَّ عَنْ مُحَمَّدِ بْنِ سَلَمَةَ ‏.‏\hadithno{3282}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“During the time of the Messenger of Allah (ﷺ) we often did not find anything to eat, and if we did, we did not have handkerchiefs, except our hands, arms and feet. Then we would pray without performing ablution.”}}
\hadithdefcmd{ibnmajah}{3283}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ حَجَّاجٍ، عَنْ رِيَاحِ بْنِ عَبِيدَةَ، عَنْ مَوْلًى، لأَبِي سَعِيدٍ عَنْ أَبِي سَعِيدٍ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ إِذَا أَكَلَ طَعَامًا قَالَ ‏ "‏ الْحَمْدُ لِلَّهِ الَّذِي أَطْعَمَنَا وَسَقَانَا وَجَعَلَنَا مُسْلِمِينَ ‏"‏ ‏.‏\hadithno{3283}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa’eed said:“Whenever the Prophet (ﷺ) ate, he would say: Al-hamdu lillahil-ladhi at’amana wa saqana wa ja’alana Muslimin (Praise is to Allah Who has fed us, given us to drink, and made us Muslims).”}}
\hadithdefcmd{ibnmajah}{3284}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا ثَوْرُ بْنُ يَزِيدَ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ أَبِي أُمَامَةَ الْبَاهِلِيِّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ كَانَ يَقُولُ إِذَا رُفِعَ طَعَامُهُ أَوْ مَا بَيْنَ يَدَيْهِ قَالَ ‏ "‏ الْحَمْدُ لِلَّهِ حَمْدًا كَثِيرًا طَيِّبًا مُبَارَكًا غَيْرَ مَكْفِيٍّ وَلاَ مُوَدَّعٍ وَلاَ مُسْتَغْنًى عَنْهُ رَبَّنَا ‏"‏ ‏.‏\hadithno{3284}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Umamah Al-Bahili that when his food, or whatever was in front of him was cleared away, the Prophet (ﷺ) used to say:“Al-hamdu lillahi hamdan kathiran tayyiban mubarakan ghaira makfiyyin wa la muwadda’in wa la mustaghnan ‘anhu, Rabbana (Praise is to Allah, abundant good and blessed praise, a never-ending praise, a praise that we will never bid farewell to and an indispensible praise, He is our Lord).”}}
\hadithdefcmd{ibnmajah}{3285}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي سَعِيدُ بْنُ أَبِي أَيُّوبَ، عَنْ أَبِي مَرْحُومٍ عَبْدِ الرَّحِيمِ، عَنْ سَهْلِ بْنِ مُعَاذِ بْنِ أَنَسٍ الْجُهَنِيِّ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ أَكَلَ طَعَامًا فَقَالَ الْحَمْدُ لِلَّهِ الَّذِي أَطْعَمَنِي هَذَا وَرَزَقَنِيهِ مِنْ غَيْرِ حَوْلٍ مِنِّي وَلاَ قُوَّةٍ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{3285}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Sahl bin Mu’adh bin Anas Al-Juhani, from his father, that the Prophet (ﷺ) said:“Whoever eats food and said: Al- hamdu lillahil-ladhi at’amani hadha wa razaqanihi min ghayri hawlin minni wa la quwwatin (Praise is to Allah Who has fed me this and provided it for me without any strength or power on my part), - his previous sins will be forgiven.”}}
\hadithdefcmd{ibnmajah}{3286}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَدَاوُدُ بْنُ رُشَيْدٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالُوا حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا وَحْشِيُّ بْنُ حَرْبِ بْنِ وَحْشِيِّ بْنِ حَرْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، وَحْشِيٍّ، أَنَّهُمْ قَالُوا يَا رَسُولَ اللَّهِ إِنَّا نَأْكُلُ وَلاَ نَشْبَعُ ‏.‏ قَالَ ‏"‏ فَلَعَلَّكُمْ تَأْكُلُونَ مُتَفَرِّقِينَ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ ‏"‏ فَاجْتَمِعُوا عَلَى طَعَامِكُمْ وَاذْكُرُوا اسْمَ اللَّهِ عَلَيْهِ يُبَارَكْ لَكُمْ فِيهِ ‏"‏ ‏.‏\hadithno{3286}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Wahshi bin Harb bin Wahshi bin Harb narrated from his father, from his grandfather, that they said:“O Messenger of Allah, we eat and do not feel full.” He said: “Perhaps you eat separately?” They said: “Yes.” He said: “Gather to eat together, and mention the Name of Allah over it, then it will be blessed for you.”}}
\hadithdefcmd{ibnmajah}{3287}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، حَدَّثَنَا سَعِيدُ بْنُ زَيْدٍ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، قَهْرَمَانُ آلِ الزُّبَيْرِ قَالَ سَمِعْتُ سَالِمَ بْنَ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ سَمِعْتُ أَبِي يَقُولُ، سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ كُلُوا جَمِيعًا وَلاَ تَفَرَّقُوا فَإِنَّ الْبَرَكَةَ مَعَ الْجَمَاعَةِ ‏"‏ ‏.‏\hadithno{3287}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Salim bin ‘Abdullah bin ‘Umar said:“I heard my father say: ‘I heard ‘Umar bin Khattab say: “The Messenger of Allah (ﷺ) said: ‘Eat together and do not eat separately, for the blessing is in being together.’”}}
\hadithdefcmd{ibnmajah}{3288}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ عَبْدِ الرَّحْمَنِ الْمُحَارِبِيُّ، حَدَّثَنَا شَرِيكٌ، عَنْ عَبْدِ الْكَرِيمِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمْ يَكُنْ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَنْفُخُ فِي طَعَامٍ وَلاَ شَرَابٍ وَلاَ يَتَنَفَّسُ فِي الإِنَاءِ ‏"‏ ‏.‏\hadithno{3288}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) never blew onto his food or drink, and he did not breathe into the vessel.”}}
\hadithdefcmd{ibnmajah}{3289}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ أَبِيهِ، سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا جَاءَ أَحَدَكُمْ خَادِمُهُ بِطَعَامِهِ فَلْيُجْلِسْهُ فَلْيَأْكُلْ مَعَهُ فَإِنْ أَبَى فَلْيُنَاوِلْهُ مِنْهُ ‏"‏ ‏.‏\hadithno{3289}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Isma’il bin Abu Khalid narrated from his father:“I heard Abu Hurairah say: ‘The Messenger of Allah (ﷺ) said: “When the servant of anyone of you brings him his food, let him make him sit by his side and eat with him, and if he refuses then let him give him some.”}}
\hadithdefcmd{ibnmajah}{3290}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا أَحَدُكُمْ قَرَّبَ إِلَيْهِ مَمْلُوكُهُ طَعَامًا قَدْ كَفَاهُ عَنَاءَهُ وَحَرَّهُ فَلْيَدْعُهُ فَلْيَأْكُلْ مَعَهُ فَإِنْ لَمْ يَفْعَلْ فَلْيَأْخُذْ لُقْمَةً فَلْيَجْعَلْهَا فِي يَدِهِ ‏"‏ ‏.‏\hadithno{3290}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“When the slave of anyone of you brings his food to him, for which he (the slave) has worked hard and endured heat, let him invite him to eat with him, and if he does not do that then let him take a morsel and put it in his hand.”}}
\hadithdefcmd{ibnmajah}{3291}{حَدَّثَنَا عَلِيُّ بْنُ الْمُنْذِرِ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا إِبْرَاهِيمُ الْهَجَرِيُّ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا جَاءَ خَادِمُ أَحَدِكُمْ بِطَعَامِهِ فَلْيُقْعِدْهُ مَعَهُ أَوْ لِيُنَاوِلْهُ مِنْهُ فَإِنَّهُ هُوَ الَّذِي وَلِيَ حَرَّهُ وَدُخَانَهُ ‏"‏ ‏.‏\hadithno{3291}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdullah that the Messenger of Allah (ﷺ) said:“When the servant of anyone of you brings his food, let him make him sit down with him or give him some of it, for he is the one who put up with its heat and smoke.”}}
\hadithdefcmd{ibnmajah}{3292}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنَا أَبِي، عَنْ يُونُسَ بْنِ أَبِي الْفُرَاتِ الإِسْكَافِ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ مَا أَكَلَ النَّبِيُّ ـ صلى الله عليه وسلم ـ عَلَى خِوَانٍ وَلاَ فِي سُكُرُّجَةٍ ‏.‏ قَالَ فَعَلاَمَ كَانُوا يَأْكُلُونَ قَالَ عَلَى السُّفَرِ ‏.‏\hadithno{3292}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Qatadah, that Anas bin Malik said:“The Prophet (ﷺ) never ate from a dish or from an individual plate.” He said: “From where did he eat?” He said: “From the dining sheet.”}}
\hadithdefcmd{ibnmajah}{3293}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ يُوسُفَ الْجُبَيْرِيُّ، حَدَّثَنَا أَبُو بَحْرٍ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، قَالَ مَا رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَكَلَ عَلَى خِوَانٍ حَتَّى مَاتَ ‏.‏\hadithno{3293}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas said:“I never saw the Messenger of Allah (ﷺ) eat from a dish until he died.”}}
\hadithdefcmd{ibnmajah}{3294}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَحْمَدَ بْنِ بَشِيرِ بْنِ ذَكْوَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ مُنِيرِ بْنِ الزُّبَيْرِ، عَنْ مَكْحُولٍ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى أَنْ يُقَامَ عَنِ الطَّعَامِ حَتَّى يُرْفَعَ ‏.‏\hadithno{3294}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Aishah that the Messenger of Allah (ﷺ) forbade standing up before the food had been cleared away}}
\hadithdefcmd{ibnmajah}{3295}{حَدَّثَنَا مُحَمَّدُ بْنُ خَلَفٍ الْعَسْقَلاَنِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ، أَنْبَأَنَا عَبْدُ الأَعْلَى، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا وُضِعَتِ الْمَائِدَةُ فَلاَ يَقُومُ رَجُلٌ حَتَّى تُرْفَعَ الْمَائِدَةُ وَلاَ يَرْفَعُ يَدَهُ وَإِنْ شَبِعَ حَتَّى يَفْرُغَ الْقَوْمُ وَلْيُعْذِرْ فَإِنَّ الرَّجُلَ يُخْجِلُ جَلِيسَهُ فَيَقْبِضُ يَدَهُ وَعَسَى أَنْ يَكُونَ لَهُ فِي الطَّعَامِ حَاجَةٌ ‏"‏ ‏.‏\hadithno{3295}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:“When a meal is served, a man should not stand up until it is removed, and he should not take his hand away, even if he is full, until the people have finished. And let him continue eating.* For a man may make his companion shy, causing him to withhold his hand, and perhaps he has a need for the food.”}}
\hadithdefcmd{ibnmajah}{3296}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا عُبَيْدُ بْنُ وَسِيمٍ الْجَمَّالُ، حَدَّثَنِي الْحَسَنُ بْنُ الْحَسَنِ، عَنْ أُمِّهِ، فَاطِمَةَ بِنْتِ الْحُسَيْنِ عَنِ الْحُسَيْنِ بْنِ عَلِيٍّ، عَنْ أُمِّهِ، فَاطِمَةَ ابْنَةِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَلاَ لاَ يَلُومَنَّ امْرُؤٌ إِلاَّ نَفْسَهُ يَبِيتُ وَفِي يَدِهِ رِيحُ غَمَرٍ ‏"‏ ‏.‏\hadithno{3296}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Husain bin ‘Ali that his mother, Fatimah the daughter of the Messenger of Allah (ﷺ), said:“The Messenger of Allah (ﷺ) said: ‘A man has no one to blame but himself, if he goes to bed with a smell emanating from his hand.’”}}
\hadithdefcmd{ibnmajah}{3297}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، حَدَّثَنَا سُهَيْلُ بْنُ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا نَامَ أَحَدُكُمْ وَفِي يَدِهِ رِيحُ غَمَرٍ فَلَمْ يَغْسِلْ يَدَهُ فَأَصَابَهُ شَىْءٌ فَلاَ يَلُومَنَّ إِلاَّ نَفْسَهُ ‏"‏ ‏.‏\hadithno{3297}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“If anyone of you goes to bed with a smell emanating from his hand, and he does not wash his hand, and something happens to him, he should not blame anyone but himself.”}}
\hadithdefcmd{ibnmajah}{3298}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّ ثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنِ ابْنِ أَبِي حُسَيْنٍ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَسْمَاءَ بِنْتِ يَزِيدَ، قَالَتْ أُتِيَ النَّبِيُّ ـ صلى الله عليه وسلم ـ بِطَعَامٍ فَعُرِضَ عَلَيْنَا فَقُلْنَا لاَ نَشْتَهِيهِ ‏.‏ فَقَالَ ‏ "‏ لاَ تَجْمَعْنَ جُوعًا وَكَذِبًا ‏"‏ ‏.‏\hadithno{3298}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Asma’ bint Yazid said:“Some food was brought to the Prophet (ﷺ) and it was offered to us. We said: ‘We do not have any appetite for it.’ He said: ‘Do not combine hunger and lies.’”}}
\hadithdefcmd{ibnmajah}{3299}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ أَبِي هِلاَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ سَوَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، - رَجُلٌ مِنْ بَنِي عَبْدِ الأَشْهَلِ - قَالَ أَتَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ وَهُوَ يَتَغَدَّى فَقَالَ ‏ "‏ ادْنُ فَكُلْ ‏"‏ ‏.‏ فَقُلْتُ إِنِّي صَائِمٌ فَيَا لَهْفَ نَفْسِي هَلاَّ كُنْتُ طَعِمْتُ مِنْ طَعَامِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{3299}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas bin Malik – a man from the tribe of Banu ‘Abdul-Ashhal – said:* “I came to the Prophet (ﷺ) when he was eating breakfast and he said: ‘Come and eat.’ I said: ‘I am fasting. Alas! Would that I had eaten of the food of the Messenger of Allah (ﷺ).’”}}
\hadithdefcmd{ibnmajah}{3300}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، حَدَّثَنِي سُلَيْمَانُ بْنُ زِيَادٍ الْحَضْرَمِيُّ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ الْحَارِثِ بْنِ جَزْءٍ الزُّبَيْدِيَّ، يَقُولُ كُنَّا نَأْكُلُ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي الْمَسْجِدِ الْخُبْزَ وَاللَّحْمَ ‏.‏\hadithno{3300}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that ‘Abdullah bin Harith bin Jaz’ Az-Zubaidi said:“At the time of the Messenger of Allah (ﷺ) we used to eat bread and meat in the mosque.”}}
\hadithdefcmd{ibnmajah}{3301}{حَدَّثَنَا أَبُو السَّائِبِ، سَلْمُ بْنُ جُنَادَةَ حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنَّا عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ نَأْكُلُ وَنَحْنُ نَمْشِي وَنَشْرَبُ وَنَحْنُ قِيَامٌ ‏.‏\hadithno{3301}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Umar said:“At the time of the Messenger of Allah (ﷺ) we used to eat while walking, and drink while standing up.”}}
\hadithdefcmd{ibnmajah}{3302}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، أَنْبَأَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُحِبُّ الْقَرْعَ ‏.‏\hadithno{3302}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:“The Prophet (ﷺ) like gourd.”}}
\hadithdefcmd{ibnmajah}{3303}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ بَعَثَتْ مَعِي أُمُّ سُلَيْمٍ بِمِكْتَلٍ فِيهِ رُطَبٌ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَلَمْ أَجِدْهُ وَخَرَجَ قَرِيبًا إِلَى مَوْلًى لَهُ دَعَاهُ فَصَنَعَ لَهُ طَعَامًا فَأَتَيْتُهُ وَهُوَ يَأْكُلُ ‏.‏ قَالَ فَدَعَانِي لآكُلَ مَعَهُ ‏.‏ قَالَ وَصَنَعَ ثَرِيدَةً بِلَحْمٍ وَقَرْعٍ ‏.‏ قَالَ فَإِذَا هُوَ يُعْجِبُهُ الْقَرْعُ ‏.‏ قَالَ فَجَعَلْتُ أَجْمَعُهُ فَأُدْنِيهِ مِنْهُ فَلَمَّا طَعِمْنَا مِنْهُ رَجَعَ إِلَى مَنْزِلِهِ وَوَضَعْتُ الْمِكْتَلَ بَيْنَ يَدَيْهِ فَجَعَلَ يَأْكُلُ وَيَقْسِمُ حَتَّى فَرَغَ مِنْ آخِرِهِ ‏.‏\hadithno{3303}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:“Umm Sulaim sent with me a basket of fresh dates for the Messenger of Allah (ﷺ), but I did not find him, as he had just gone out to a freed slave of his who had invited him and made food for him. I came to him and he was eating, and he called me to eat with him. He (the freed slave) had served him Tharid with meat and gourd, and he liked the gourd, so I started to collect the (pieces of) gourd and put them near him. When he had eaten he went back to him house and I put the basket (of dates) before him, and he started to eat them and share them, until he finished the last of them.”}}
\hadithdefcmd{ibnmajah}{3304}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ حَكِيمِ بْنِ جَابِرٍ، عَنْ أَبِيهِ، قَالَ دَخَلْتُ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فِي بَيْتِهِ وَعِنْدَهُ هَذِهِ الدُّبَّاءُ فَقُلْتُ أَىُّ شَىْءٍ هَذَا قَالَ ‏ "‏ هَذَا الْقَرْعُ هُوَ الدُّبَّاءُ نُكَثِّرُ بِهِ طَعَامَنَا ‏"‏ ‏.‏\hadithno{3304}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hakin bin Jabr that his father said:“I entered upon the Prophet (ﷺ) in his house, and he had some of this gourd. I said: ‘What is this?’ He said: ‘This is Qar’; it is Dubba’. We augment our food with it.”}}
\hadithdefcmd{ibnmajah}{3305}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ الْخَلاَّلُ الدِّمَشْقِيُّ، حَدَّثَنَا يَحْيَى بْنُ صَالِحٍ، حَدَّثَنِي سُلَيْمَانُ بْنُ عَطَاءٍ الْجَزَرِيُّ، حَدَّثَنِي مَسْلَمَةُ بْنُ عَبْدِ اللَّهِ الْجُهَنِيُّ، عَنْ عَمِّهِ أَبِي مَشْجَعَةَ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ سَيِّدُ طَعَامِ أَهْلِ الدُّنْيَا وَأَهْلِ الْجَنَّةِ اللَّحْمُ ‏"‏ ‏.‏\hadithno{3305}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Darda’ that the Messenger of Allah (ﷺ) said:“The best food of the people of this world and the people of Paradise is meat.’”}}
\hadithdefcmd{ibnmajah}{3306}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ الدِّمَشْقِيُّ، حَدَّثَنَا يَحْيَى بْنُ صَالِحٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ عَطَاءٍ الْجَزَرِيُّ، حَدَّثَنَا مَسْلَمَةُ بْنُ عَبْدِ اللَّهِ الْجُهَنِيُّ، عَنْ عَمِّهِ أَبِي مَشْجَعَةَ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ مَا دُعِيَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَى لَحْمٍ قَطُّ إِلاَّ أَجَابَ وَلاَ أُهْدِيَ لَهُ لَحْمٌ قَطُّ إِلاَّ قَبِلَهُ ‏.‏\hadithno{3306}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Darda’ said:“The Messenger of Allah (ﷺ) was never invited to eat meat but he would respond, and he was never offered meat as a gift but he would accept it.”}}
\hadithdefcmd{ibnmajah}{3307}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ الْعَبْدِيُّ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، قَالاَ حَدَّثَنَا أَبُو حَيَّانَ التَّيْمِيُّ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أُتِيَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ذَاتَ يَوْمٍ بِلَحْمٍ فَرُفِعَ إِلَيْهِ الذِّرَاعُ وَكَانَتْ تُعْجِبُهُ فَنَهَسَ مِنْهَا ‏.‏\hadithno{3307}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:“One day some meat was brought to the Messenger of Allah (ﷺ) and the foreleg was offered to him which he liked, so he bit it with his front teeth.”}}
\hadithdefcmd{ibnmajah}{3308}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ مِسْعَرٍ، حَدَّثَنِي شَيْخٌ، مِنْ فَهْمٍ - قَالَ وَأَظُنُّهُ يُسَمَّى مُحَمَّدَ بْنَ عَبْدِ اللَّهِ - أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ جَعْفَرٍ يُحَدِّثُ ابْنَ الزُّبَيْرِ وَقَدْ نَحَرَ لَهُمْ جَزُورًا أَوْ بَعِيرًا أَنَّهُ سَمِعَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ - قَالَ وَالْقَوْمُ يُلْقُونَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ اللَّحْمَ - يَقُولُ ‏ "‏ أَطْيَبُ اللَّحْمِ لَحْمُ الظَّهْرِ ‏"‏ ‏.‏\hadithno{3308}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘Abdullah bin Ja’far told Ibn Zubair, who had slaughtered a camel for them, that he heard the Messenger of Allah (ﷺ), and he (‘Abdullah) said:“Some people were bringing meat to the Messenger of Allah (ﷺ) and he said: ‘The best meat is the meat of the back.’”}}
\hadithdefcmd{ibnmajah}{3309}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ مَا أَعْلَمُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ رَأَى شَاةً سَمِيطًا حَتَّى لَحِقَ بِاللَّهِ عَزَّ وَجَلَّ ‏.‏\hadithno{3309}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas bin Malik said:“I do not know of the Messenger of Allah (ﷺ) ever seeing a roasted sheep* until he met Allah.”}}
\hadithdefcmd{ibnmajah}{3310}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا كَثِيرُ بْنُ سُلَيْمٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ مَا رُفِعَ مِنْ بَيْنِ يَدَىْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَضْلُ شِوَاءٍ قَطُّ وَلاَ حُمِلَتْ مَعَهُ طِنْفِسَةٌ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{3310}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:“No leftovers of roast meat* were ever cleared from in front of the Messenger of Allah (ﷺ), and no carpet was ever carried with him.”}}
\hadithdefcmd{ibnmajah}{3311}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا ابْنُ لَهِيعَةَ، أَخْبَرَنِي سُلَيْمَانُ بْنُ زِيَادٍ الْحَضْرَمِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ الْجَزْءِ الزُّبَيْدِيِّ، قَالَ أَكَلْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ طَعَامًا فِي الْمَسْجِدِ لَحْمًا قَدْ شُوِيَ فَمَسَحْنَا أَيْدِيَنَا بِالْحَصْبَاءِ ثُمَّ قُمْنَا فَصَلَّى وَلَمْ يَتَوَضَّأْ ‏.‏\hadithno{3311}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Abdullah bin Harith bin Jaz’ Az-Zubaidi said:“We ate food with the Messenger of Allah (ﷺ) in the mosque, meat that had been roasted. Then we wiped our hands on the pebbles and got up to perform prayer without performing ablution.”}}
\hadithdefcmd{ibnmajah}{3312}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَسَدٍ، حَدَّثَنَا جَعْفَرُ بْنُ عَوْنٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ أَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ رَجُلٌ فَكَلَّمَهُ فَجَعَلَ تُرْعَدُ فَرَائِصُهُ فَقَالَ لَهُ ‏ "‏ هَوِّنْ عَلَيْكَ فَإِنِّي لَسْتُ بِمَلِكٍ إِنَّمَا أَنَا ابْنُ امْرَأَةٍ تَأْكُلُ الْقَدِيدَ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ إِسْمَاعِيلُ وَحْدَهُ وَصَلَهُ ‏.‏\hadithno{3312}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Mas`ud said:“A man came to the Prophet (ﷺ) and his voice trembled out of awe as he spoke to him. The Prophet said to him, “Be calm, for I am not a king. Verily, I am only the son of a woman who ate dried meat.”}}
\hadithdefcmd{ibnmajah}{3313}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَابِسٍ، أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ، قَالَتْ لَقَدْ كُنَّا نَرْفَعُ الْكُرَاعَ فَيَأْكُلُهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بَعْدَ خَمْسَ عَشْرَةَ مِنَ الأَضَاحِيِّ ‏.‏\hadithno{3313}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Aishah said:“We used to store trotters and the Messenger of Allah (ﷺ) would eat them fifteen days after the sacrifice.”}}
\hadithdefcmd{ibnmajah}{3314}{حَدَّثَنَا أَبُو مُصْعَبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أُحِلَّتْ لَنَا مَيْتَتَانِ وَدَمَانِ فَأَمَّا الْمَيْتَتَانِ فَالْحُوتُ وَالْجَرَادُ وَأَمَّا الدَّمَانِ فَالْكَبِدُ وَالطِّحَالُ ‏"‏ ‏.‏\hadithno{3314}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdullah bin ‘Umar that the Messenger of Allah (ﷺ) said:“Two kinds of dead meat and two kinds of blood have been permitted to us. The two kinds of dead meat are fish and locusts, and the two kinds of blood are the liver and spleen.”}}
\hadithdefcmd{ibnmajah}{3315}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، حَدَّثَنَا عِيسَى بْنُ أَبِي عِيسَى، عَنْ رَجُلٍ، - أُرَاهُ مُوسَى - عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ سَيِّدُ إِدَامِكُمُ الْمِلْحُ ‏"‏ ‏.‏\hadithno{3315}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:‘The best of your seasonings is salt.”}}
\hadithdefcmd{ibnmajah}{3316}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي الْحَوَارِيِّ، حَدَّثَنَا مَرْوَانُ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ نِعْمَ الإِدَامُ الْخَلُّ ‏"‏ ‏.‏\hadithno{3316}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Aishah that the Messenger of Allah (ﷺ) said:“What a blessed condiment vinegar is.”}}
\hadithdefcmd{ibnmajah}{3317}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا قَيْسُ بْنُ الرَّبِيعِ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ نِعْمَ الإِدَامُ الْخَلُّ ‏"‏ ‏.‏\hadithno{3317}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that the Messenger of Allah (ﷺ) said:“What a blessed condiment vinegar is.”}}
\hadithdefcmd{ibnmajah}{3318}{حَدَّثَنَا الْعَبَّاسُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا عَنْبَسَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ مُحَمَّدِ بْنِ زَاذَانَ، أَنَّهُ حَدَّثَهُ قَالَ حَدَّثَتْنِي أُمُّ سَعْدٍ، قَالَتْ دَخَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَلَى عَائِشَةَ وَأَنَا عِنْدَهَا فَقَالَ ‏"‏ هَلْ مِنْ غَدَاءٍ ‏"‏ ‏.‏ قَالَتْ عِنْدَنَا خُبْزٌ وَتَمْرٌ وَخَلٌّ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ نِعْمَ الإِدَامُ الْخَلُّ اللَّهُمَّ بَارِكْ فِي الْخَلِّ فَإِنَّهُ كَانَ إِدَامَ الأَنْبِيَاءِ قَبْلِي وَلَمْ يَفْتَقِرْ بَيْتٌ فِيهِ خَلٌّ ‏"‏ ‏.‏\hadithno{3318}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{Umm Sa’d said:“The Messenger of Allah (ﷺ) entered upon ‘Aishah, when I was with her, and said: ‘Is there any food?’ She said: ‘We have bread, dates and vinegar.’ The Messenger of Allah (ﷺ) said: ‘What a blessed condiment vinegar is. O Allah, bless vinegar, for it was the condiment of the Prophets before me, and no house will ever be poor in which there is vinegar.’”}}
\hadithdefcmd{ibnmajah}{3319}{حَدَّثَنَا الْحُسَيْنُ بْنُ مَهْدِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اِئْتَدِمُوا بِالزَّيْتِ وَادَّهِنُوا بِهِ فَإِنَّهُ مِنْ شَجَرَةٍ مُبَارَكَةٍ ‏"‏ ‏.‏\hadithno{3319}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Umar that the Messenger of Allah (ﷺ) said:‘Season (your food) with olive oil and anoint yourselves with it, for it comes from a blessed tree.”}}
\hadithdefcmd{ibnmajah}{3320}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ، حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، عَنْ جَدِّهِ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ كُلُوا الزَّيْتَ وَادَّهِنُوا بِهِ فَإِنَّهُ مُبَارَكٌ ‏"‏ ‏.‏\hadithno{3320}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Abdullah bin Sa’eed narrated that his grandfather said:“I heard Abu Hurairah say: The Messenger of Allah (ﷺ) said: ‘Eat (olive) oil and anoint yourselves with it, for it is blessed.’”}}
\hadithdefcmd{ibnmajah}{3321}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، عَنْ جَعْفَرِ بْنِ بُرْدٍ الرَّاسِبِيِّ، حَدَّثَتْنِي مَوْلاَتِي أُمُّ سَالِمٍ الرَّاسِبِيَّةُ، قَالَتْ سَمِعْتُ عَائِشَةَ، تَقُولُ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا أُتِيَ بِلَبَنٍ قَالَ ‏ "‏ بَرَكَةٌ أَوْ بَرَكَتَانِ ‏"‏ ‏.‏\hadithno{3321}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{I heard ‘Aishah say:“The Messenger of Allah (ﷺ) would say, when milk was brought to him: ‘A blessing,’ or ‘Two blessings.’”}}
\hadithdefcmd{ibnmajah}{3322}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَطْعَمَهُ اللَّهُ طَعَامًا فَلْيَقُلِ اللَّهُمَّ بَارِكْ لَنَا فِيهِ وَارْزُقْنَا خَيْرًا مِنْهُ ‏.‏ وَمَنْ سَقَاهُ اللَّهُ لَبَنًا فَلْيَقُلِ اللَّهُمَّ بَارِكْ لَنَا فِيهِ وَزِدْنَا مِنْهُ فَإِنِّي لاَ أَعْلَمُ مَا يُجْزِئُ مِنَ الطَّعَامِ وَالشَّرَابِ إِلاَّ اللَّبَنُ ‏"‏ ‏.‏\hadithno{3322}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“Whoever is given food by Allah, let him say: Allahumma barik lana fihi wa arzuqna khairan minhu (O Allah, bless it for us and provide us with something better than it). And whoever is given milk to drink by Allah, let him say: Allahumma barik lana fihi wa zidna minhu (O Allah, bless it for us and give us more of it). For I do not know of any food or drink that suffices, apart from milk.”}}
\hadithdefcmd{ibnmajah}{3323}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، وَعَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، قَالُوا حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُحِبُّ الْحَلْوَاءَ وَالْعَسَلَ ‏.‏\hadithno{3323}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{(It was narrated that ‘Aishah said:“The Messenger of Allah 9saw) used to like sweets and honey.”}}
\hadithdefcmd{ibnmajah}{3324}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَتْ أُمِّي تُعَالِجُنِي لِلسُّمْنَةِ تُرِيدُ أَنْ تُدْخِلَنِي عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَمَا اسْتَقَامَ لَهَا ذَلِكَ حَتَّى أَكَلْتُ الْقِثَّاءَ بِالرُّطَبِ فَسَمِنْتُ كَأَحْسَنِ سُمْنَةٍ ‏.‏\hadithno{3324}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that ‘Aishah said:“My mother was trying to fatten me up when she wanted to send me to the Messenger of Allah (ﷺ) (when she got married), but nothing worked until I ate cucumbers with dates; then I grew plump like the best kind of plump.”}}
\hadithdefcmd{ibnmajah}{3325}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، وَإِسْمَاعِيلُ بْنُ مُوسَى، قَالاَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَأْكُلُ الْقِثَّاءَ بِالرُّطَبِ ‏.‏\hadithno{3325}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated ‘Abdullah bin Ja’far said:“I saw the Messenger of Allah (ﷺ) eating cucumbers with dates.”}}
\hadithdefcmd{ibnmajah}{3326}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، وَعَمْرُو بْنُ رَافِعٍ، قَالاَ حَدَّثَنَا يَعْقُوبُ بْنُ الْوَلِيدِ بْنِ أَبِي هِلاَلٍ الْمَدَنِيُّ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَأْكُلُ الرُّطَبَ بِالْبِطِّيخِ ‏.‏\hadithno{3326}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Sahl bin Sa’d said:“The Messenger of Allah (ﷺ) used to eat dates with melon.”}}
\hadithdefcmd{ibnmajah}{3327}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي الْحَوَارِيِّ الدِّمَشْقِيُّ، حَدَّثَنَا مَرْوَانُ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ بَيْتٌ لاَ تَمْرَ فِيهِ جِيَاعٌ أَهْلُهُ ‏"‏ ‏.‏\hadithno{3327}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Aishah that the Messenger of Allah (ﷺ) said:“A house in which there are no dates, its people will go hungry.”}}
\hadithdefcmd{ibnmajah}{3328}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، حَدَّثَنَا هِشَامُ بْنُ سَعْدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَلِيِّ بْنِ أَبِي رَافِعٍ، عَنْ جَدَّتِهِ، سَلْمَى أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ بَيْتٌ لاَ تَمْرَ فِيهِ كَالْبَيْتِ لاَ طَعَامَ فِيهِ ‏"‏ ‏.‏\hadithno{3328}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Ubaidullah bin Abu Rafi’, from his grandmother Salma, that the Prophet (ﷺ) said:“A house in which there are no dates is like a house in which there is no food.”}}
\hadithdefcmd{ibnmajah}{3329}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، وَيَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، قَالاَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، أَخْبَرَنِي سُهَيْلُ بْنُ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ إِذَا أُتِيَ بِأَوَّلِ الثَّمَرَةِ قَالَ ‏ "‏ اللَّهُمَّ بَارِكْ لَنَا فِي مَدِينَتِنَا وَفِي ثِمَارِنَا وَفِي مُدِّنَا وَفِي صَاعِنَا بَرَكَةً مَعَ بَرَكَةٍ ‏"‏ ‏.‏ ثُمَّ يُنَاوِلُهُ أَصْغَرَ مَنْ بِحَضْرَتِهِ مِنَ الْوِلْدَانِ ‏.‏\hadithno{3329}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that when the first fruits (of the season) were brought, the Messenger of Allah (ﷺ) would say:“O Allah, bless us in our city and in our fruits, in our Mudd and in our Sa’,* blessing upon blessing.” Then he would give it to the smallest of the children present}}
\hadithdefcmd{ibnmajah}{3330}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا يَحْيَى بْنُ مُحَمَّدِ بْنِ قَيْسٍ الْمَدَنِيُّ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ كُلُوا الْبَلَحَ بِالتَّمْرِ كُلُوا الْخَلَقَ بِالْجَدِيدِ فَإِنَّ الشَّيْطَانَ يَغْضَبُ وَيَقُولُ بَقِيَ ابْنُ آدَمَ حَتَّى أَكَلَ الْخَلَقَ بِالْجَدِيدِ ‏"‏ ‏.‏\hadithno{3330}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Aishah that the Messenger of Allah (ﷺ) said:“Eat unripe dates with ripe one and eat old dates with new ones, for Satan gets angry and says: ‘The son of Adam will survive so long as he eats old dates with new ones.’”}}
\hadithdefcmd{ibnmajah}{3331}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ جَبَلَةَ بْنِ سُحَيْمٍ، سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يَقْرِنَ الرَّجُلُ بَيْنَ التَّمْرَتَيْنِ حَتَّى يَسْتَأْذِنَ أَصْحَابَهُ ‏.‏\hadithno{3331}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn ‘Umar said:“The Messenger of Allah (ﷺ) forbade eating two dates at once unless he asks his companions permission to do so.”}}
\hadithdefcmd{ibnmajah}{3332}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا أَبُو عَامِرٍ الْخَزَّازُ، عَنِ الْحَسَنِ، عَنْ سَعْدٍ، مَوْلَى أَبِي بَكْرٍ - وَكَانَ سَعْدٌ يَخْدُمُ النَّبِيَّ ـ صلى الله عليه وسلم ـ وَكَانَ يُعْجِبُهُ حَدِيثُهُ - أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ نَهَى عَنِ الإِقْرَانِ ‏.‏ يَعْنِي فِي التَّمْرِ ‏.‏\hadithno{3332}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Sa’d, the freed slave of Abu Bakr – and Sa’d used to serve the Messenger of Allah (ﷺ) and he liked this Hadith – that the Prophet (ﷺ) forbade eating two dates at once}}
\hadithdefcmd{ibnmajah}{3333}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا أَبُو قُتَيْبَةَ، عَنْ هَمَّامٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أُتِيَ بِتَمْرٍ عَتِيقٍ فَجَعَلَ يُفَتِّشُهُ ‏.‏\hadithno{3333}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Anas bin Malik said:“I saw the Messenger of Allah (ﷺ) when he was brought some old dates; he started to inspect them.”}}
\hadithdefcmd{ibnmajah}{3334}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا صَدَقَةُ بْنُ خَالِدٍ، حَدَّثَنِي ابْنُ جَابِرٍ، حَدَّثَنِي سُلَيْمُ بْنُ عَامِرٍ، عَنِ ابْنَىْ، بُسْرٍ السُّلَمِيَّيْنِ قَالاَ دَخَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَوَضَعْنَا تَحْتَهُ قَطِيفَةً لَنَا صَبَبْنَاهَا لَهُ صَبًّا فَجَلَسَ عَلَيْهَا فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ عَلَيْهِ الْوَحْىَ فِي بَيْتِنَا وَقَدَّمْنَا لَهُ زُبْدًا وَتَمْرًا وَكَانَ يُحِبُّ الزُّبْدَ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{3334}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that the two sons of Busr, who were of the tribe of Sulaim, said:“The Messenger of Allah (ﷺ) entered upon us. We placed a velvet cloth of ours beneath him and sprinkled water on it.* He sat on it, and Allah sent down Revelation to him in our house. We offered him butter and dates, and he (ﷺ) liked butter.”}}
\hadithdefcmd{ibnmajah}{3335}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، وَسُوَيْدُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، حَدَّثَنِي أَبِي قَالَ، سَأَلْتُ سَهْلَ بْنَ سَعْدٍ هَلْ رَأَيْتَ النَّقِيَّ قَالَ مَا رَأَيْتُ النَّقِيَّ حَتَّى قُبِضَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ فَقُلْتُ فَهَلْ كَانَ لَهُمْ مَنَاخِلُ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ مَا رَأَيْتُ مُنْخُلاً حَتَّى قُبِضَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ قُلْتُ فَكَيْفَ كُنْتُمْ تَأْكُلُونَ الشَّعِيرَ غَيْرَ مَنْخُولٍ قَالَ نَعَمْ نَنْفُخُهُ فَيَطِيرُ مِنْهُ مَا طَارَ وَمَا بَقِيَ ثَرَّيْنَاهُ ‏.‏\hadithno{3335}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Bukhari}\hadithtrans{‘Abdul-‘Aziz bin Abu Hazim said:My father told me: I asked Sahl bin Sa’d: “Did you ever see dough made from well-sifted flour?” He said: “I never saw dough made from well-sifted flour until the Messenger of Allah (ﷺ) passed away.” I said: “Did they have sieves at the time of the Messenger of Allah (ﷺ)?” He said: “I never saw a sieve until the Messenger of Allah (ﷺ) passed away.” I said: “How did you eat barley that was not sifted?” He said: “We used to blow on it, and whatever flew away, flew away, and whatever was left we made dough with it.”}}
\hadithdefcmd{ibnmajah}{3336}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، أَخْبَرَنِي بَكْرُ بْنُ سَوَادَةَ، أَنَّ حَنَشَ بْنَ عَبْدِ اللَّهِ، حَدَّثَهُ عَنْ أُمِّ أَيْمَنَ، أَنَّهَا غَرْبَلَتْ دَقِيقًا فَصَنَعَتْهُ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ رَغِيفًا فَقَالَ ‏"‏ مَا هَذَا ‏"‏ ‏.‏ قَالَتْ طَعَامٌ نَصْنَعُهُ بِأَرْضِنَا فَأَحْبَبْتُ أَنْ أَصْنَعَ مِنْهُ لَكَ رَغِيفًا ‏.‏ فَقَالَ ‏"‏ رُدِّيهِ فِيهِ ثُمَّ اعْجِنِيهِ ‏"‏ ‏.‏\hadithno{3336}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Fouad Abd al-Baqi: Hasan Isnaad; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Umm Ayman that she sifted some flour and made a loaf of bread for the Prophet (ﷺ). He said:“What is this?” She said: “It is food that we make in our land, and I wanted to make a loaf of it for you. He said: “Fold it onto itself and knead it.”}}
\hadithdefcmd{ibnmajah}{3337}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ الدِّمَشْقِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عُثْمَانَ أَبُو الْجَمَاهِرِ، حَدَّثَنَا سَعِيدُ بْنُ بَشِيرٍ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ مَا رَأَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ رَغِيفًا مُحَوَّرًا بِوَاحِدٍ مِنْ عَيْنَيْهِ حَتَّى لَحِقَ بِاللَّهِ ‏.‏\hadithno{3337}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:“The Messenger of Allah (ﷺ) never saw a thin loaf made from well-sifted flour with his own eyes, until he met Allah.”}}
\hadithdefcmd{ibnmajah}{3338}{حَدَّثَنَا أَبُو عُمَيْرٍ، عِيسَى بْنُ مُحَمَّدِ بْنِ النَّحَّاسِ الرَّمْلِيُّ حَدَّثَنَا ضَمْرَةُ بْنُ رَبِيعَةَ، عَنِ ابْنِ عَطَاءٍ، عَنْ أَبِيهِ، قَالَ زَارَ أَبُو هُرَيْرَةَ قَوْمَهُ بِيُبْنَا فَأَتَوْهُ بِرُقَاقٍ مِنْ رُقَاقِ الأُوَلِ فَبَكَى وَقَالَ مَا رَأَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ هَذَا بِعَيْنِهِ قَطُّ ‏.‏\hadithno{3338}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Ata that his father said:“Abu Hurairah visited his people, meaning, a village” – I (one of the narrators) think he said: “Yuna” – “And they brought him some of the first thin loaves of bread. He wept and said: ‘The Messenger of Allah (ﷺ) never saw such a thing with his own eyes.’”}}
\hadithdefcmd{ibnmajah}{3339}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، وَأَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، قَالاَ حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، قَالَ كُنَّا نَأْتِي أَنَسَ بْنَ مَالِكٍ - قَالَ إِسْحَاقُ وَخَبَّازُهُ قَائِمٌ وَقَالَ الدَّارِمِيُّ وَخِوَانُهُ مَوْضُوعٌ - فَقَالَ يَوْمًا كُلُوا فَمَا أَعْلَمُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ رَأَى رَغِيفًا مُرَقَّقًا بِعَيْنِهِ حَتَّى لَحِقَ بِاللَّهِ وَلاَ شَاةً سَمِيطًا قَطُّ ‏.‏\hadithno{3339}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Qatadah said:“We used to go to (visit) Anas bin Malik.” (One of the narrators) Ishaq said: “And his baker was standing there.” (In another narration) Darimi said: “And his table was set. He said one day: ‘(Come and) eat, for the Messenger of Allah (ﷺ) never saw any thin loaf of bread until he met Allah, nor any roasted sheep (with skin).’”}}
\hadithdefcmd{ibnmajah}{3340}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ الضَّحَّاكِ السُّلَمِيُّ أَبُو الْحَارِثِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا مُحَمَّدُ بْنُ طَلْحَةَ، عَنْ عُثْمَانَ بْنِ يَحْيَى، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَوَّلُ مَا سَمِعْنَا بِالْفَالُوذَجِ، أَنَّ جِبْرِيلَ، عَلَيْهِ السَّلاَمُ أَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَ إِنَّ أُمَّتَكَ تُفْتَحُ عَلَيْهِمُ الأَرْضُ فَيُفَاضُ عَلَيْهِمْ مِنَ الدُّنْيَا حَتَّى إِنَّهُمْ لَيَأْكُلُونَ الْفَالُوذَجَ ‏.‏ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ وَمَا الْفَالُوذَجُ ‏"‏ ‏.‏ قَالَ يَخْلِطُونَ السَّمْنَ وَالْعَسَلَ جَمِيعًا ‏.‏ فَشَهَقَ النَّبِيُّ ـ صلى الله عليه وسلم ـ لِذَلِكَ شَهْقَةً ‏.‏\hadithno{3340}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Munkar; Shuaib Al Arnaut: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The first we heard of Faludhaj* was when Jibril (as) came to the Prophet (ﷺ) and said: ‘The world will be opened for your nation and they will conquer the world, until they eat Faludhaj.’ The Prophet (ﷺ) said: ‘What is Faludhaj?’ He said: ‘They mix ghee and honey together.’ At that, the Prophet (ﷺ) sobbed.”}}
\hadithdefcmd{ibnmajah}{3341}{حَدَّثَنَا هَدِيَّةُ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى السِّيْنَانِيُّ، حَدَّثَنَا الْحُسَيْنُ بْنُ وَاقِدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ذَاتَ يَوْمٍ ‏"‏ وَدِدْتُ لَوْ أَنَّ عِنْدَنَا خُبْزَةً بَيْضَاءَ مِنْ بُرَّةٍ سَمْرَاءَ مُلَبَّقَةٍ بِسَمْنٍ نَأْكُلُهَا ‏"‏ ‏.‏ قَالَ فَسَمِعَ بِذَلِكَ رَجُلٌ مِنَ الأَنْصَارِ فَاتَّخَذَهُ فَجَاءَ بِهِ إِلَيْهِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ فِي أَىِّ شَىْءٍ كَانَ هَذَا السَّمْنُ ‏"‏ ‏.‏ قَالَ فِي عُكَّةِ ضَبٍّ ‏.‏ قَالَ فَأَبَى أَنْ يَأْكُلَهُ ‏.‏\hadithno{3341}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Umar said:“One day, the Messenger of Allah (ﷺ) said: ‘I wish that we had some white bread made of brown wheat, softened with ghee, that we could eat.’ A man from among the Ansar heard that, so he took some (of that food) and brought it to him. The Messenger of Allah (ﷺ) said: ‘Where was this ghee kept?’ He said: ‘In a container made of mastigure skin.’ And he refused to eat it.”}}
\hadithdefcmd{ibnmajah}{3342}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا عُثْمَانُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا حُمَيْدُ الطَّوِيلُ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ صَنَعَتْ أُمُّ سُلَيْمٍ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ خُبْزَةً وَضَعَتْ فِيهَا شَيْئًا مِنْ سَمْنٍ ثُمَّ قَالَتِ اذْهَبْ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَادْعُهُ قَالَ فَأَتَيْتُهُ فَقُلْتُ أُمِّي تَدْعُوكَ ‏.‏ قَالَ فَقَامَ وَقَالَ لِمَنْ كَانَ عِنْدَهُ مِنَ النَّاسِ ‏"‏ قُومُوا ‏"‏ ‏.‏ قَالَ فَسَبَقْتُهُمْ إِلَيْهَا فَأَخْبَرْتُهَا فَجَاءَ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ هَاتِي مَا صَنَعْتِ ‏"‏ ‏.‏ فَقَالَتْ إِنَّمَا صَنَعْتُهُ لَكَ وَحْدَكَ ‏.‏ فَقَالَ ‏"‏ هَاتِيهِ ‏"‏ ‏.‏ فَقَالَ ‏"‏ يَا أَنَسُ أَدْخِلْ عَلَىَّ عَشْرَةً عَشْرَةً ‏"‏ ‏.‏ قَالَ فَمَا زِلْتُ أُدْخِلُ عَلَيْهِ عَشْرَةً عَشْرَةً فَأَكَلُوا حَتَّى شَبِعُوا وَكَانُوا ثَمَانِينَ ‏.‏\hadithno{3342}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:“Umm Sulaim made some bread for the Prophet (ﷺ), and she put a little ghee on it. Then she said: ‘Go to the Prophet (ﷺ) and invite him (to come and eat).’ So I went and told him: ‘My mother is inviting you (to come and eat).’ So he stood up, and said to the people who were with him: ‘Get up.’ I went ahead of him and told her. Then the Prophet (ﷺ) came and said: ‘Bring what you have made.’ She said: ‘I only made it for you alone.’ He said: ‘Bring it.’ Then he said: ‘O Anas, bring (them) in to me ten by ten.’ So I kept bringing them in ten by ten, and they ate their fill, and there were eighty of them.”}}
\hadithdefcmd{ibnmajah}{3343}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، عَنْ يَزِيدَ بْنِ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ وَالَّذِي نَفْسِي بِيَدِهِ مَا شَبِعَ نَبِيُّ اللَّهِ ـ صلى الله عليه وسلم ـ ثَلاَثَةَ أَيَّامٍ تِبَاعًا مِنْ خُبْزِ الْحِنْطَةِ حَتَّى تَوَفَّاهُ اللَّهُ عَزَّ وَجَلَّ ‏.‏\hadithno{3343}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:“By the One in Whose Hand is my soul, the Prophet of Allah (ﷺ) never ate his fill of wheat bread for three days in a row, until Allah took his soul.”}}
\hadithdefcmd{ibnmajah}{3344}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، حَدَّثَنَا زَائِدَةُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ مَا شَبِعَ آلُ مُحَمَّدٍ ـ صلى الله عليه وسلم ـ مُنْذُ قَدِمُوا الْمَدِينَةَ ثَلاَثَ لَيَالٍ تِبَاعًا مِنْ خُبْزِ بُرٍّ حَتَّى تُوُفِّيَ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{3344}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{it was narrated that ‘Aishah said:“The family of Muhammad (ﷺ) never ate their fill of wheat bread for three nights in a row, from the time they came to Al-Madinah until he passed away.”}}
\hadithdefcmd{ibnmajah}{3345}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ لَقَدْ تُوُفِّيَ النَّبِيُّ ـ صلى الله عليه وسلم ـ وَمَا فِي بَيْتِي مِنْ شَىْءٍ يَأْكُلُهُ ذُو كَبِدٍ إِلاَّ شَطْرُ شَعِيرٍ فِي رَفٍّ لِي فَأَكَلْتُ مِنْهُ حَتَّى طَالَ عَلَىَّ فَكِلْتُهُ فَفَنِيَ ‏.‏\hadithno{3345}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Aishah said:“When the Prophet (ﷺ) passed away, there was nothing in my house that any living soul could eat, except a little bit of barley on a shelf of mine. I ate it for a long time, then I weighed it and soon it was all gone.”}}
\hadithdefcmd{ibnmajah}{3346}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ يَزِيدَ، يُحَدِّثُ عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ مَا شَبِعَ آلُ مُحَمَّدٍ ـ صلى الله عليه وسلم ـ مِنْ خُبْزِ الشَّعِيرِ حَتَّى قُبِضَ ‏.‏\hadithno{3346}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Aishah said:“The family of Muhammad (ﷺ) never ate their fill of barley bread until he was taken (i.e. died).”}}
\hadithdefcmd{ibnmajah}{3347}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُعَاوِيَةَ الْجُمَحِيُّ، حَدَّثَنَا ثَابِتُ بْنُ يَزِيدَ، عَنْ هِلاَلِ بْنِ خَبَّابٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَبِيتُ اللَّيَالِيَ الْمُتَتَابِعَةَ طَاوِيًا وَأَهْلُهُ لاَ يَجِدُونَ الْعَشَاءَ وَكَانَ عَامَّةَ خُبْزِهِمْ خُبْزُ الشَّعِيرِ ‏.‏\hadithno{3347}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) used to spend many nights in a row hungry and his family could find no supper, and usually their bread was barley bread.”}}
\hadithdefcmd{ibnmajah}{3348}{حَدَّثَنَا يَحْيَى بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، - وَكَانَ يُعَدُّ مِنَ الأَبْدَالِ - حَدَّثَنَا بَقِيَّةُ، حَدَّثَنَا يُوسُفُ بْنُ أَبِي كَثِيرٍ، عَنْ نُوحِ بْنِ ذَكْوَانَ، عَنِ الْحَسَنِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَبِسَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ الصُّوفَ وَاحْتَذَى الْمَخْصُوفَ ‏.‏ وَقَالَ أَكَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بَشِعًا وَلَبِسَ خَشِنًا ‏.‏ فَقِيلَ لِلْحَسَنِ مَا الْبَشِعُ قَالَ غَلِيظُ الشَّعِيرِ مَا كَانَ يُسِيغُهُ إِلاَّ بِجُرْعَةِ مَاءٍ ‏.‏\hadithno{3348}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hasan that Anas bin Malik said:“The Messenger of Allah (ﷺ) wore wool, and his shows were sandals.”}}
\hadithdefcmd{ibnmajah}{3349}{حَدَّثَنَا هِشَامُ بْنُ عَبْدِ الْمَلِكِ الْحِمْصِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، حَدَّثَتْنِي أُمِّي، عَنْ أُمِّهَا، أَنَّهَا سَمِعَتِ الْمِقْدَامَ بْنَ مَعْدِيكَرِبَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَا مَلأَ آدَمِيٌّ وِعَاءً شَرًّا مِنْ بَطْنٍ حَسْبُ الآدَمِيِّ لُقَيْمَاتٌ يُقِمْنَ صُلْبَهُ فَإِنْ غَلَبَتِ الآدَمِيَّ نَفْسُهُ فَثُلُثٌ لِلطَّعَامِ وَثُلُثٌ لِلشَّرَابِ وَثُلُثٌ لِلنَّفَسِ ‏"‏ ‏.‏\hadithno{3349}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Miqdam bin Madikarib said:“I heard the Messenger of Allah (ﷺ) say: ‘A human being fills no worse vessel than his stomach. It is sufficient for a human being to eat a few mouthfuls to keep his spine straight. But if he must (fill it), then one third of food, one third for drink and one third for air.’”}}
\hadithdefcmd{ibnmajah}{3350}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ أَبُو يَحْيَى، عَنْ يَحْيَى الْبَكَّاءِ، عَنِ ابْنِ عُمَرَ، قَالَ تَجَشَّأَ رَجُلٌ عِنْدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ كُفَّ جُشَاءَكَ عَنَّا فَإِنَّ أَطْوَلَكُمْ جُوعًا يَوْمَ الْقِيَامَةِ أَكْثَرُكُمْ شِبَعًا فِي دَارِ الدُّنْيَا ‏"‏ ‏.‏\hadithno{3350}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Umar said:“A man burped in the presence of the Prophet (ﷺ) and he said: ‘Withhold your burps from us! For the most hungry of you on the Day of Resurrection will be those who most ate their fill in this world.’”}}
\hadithdefcmd{ibnmajah}{3351}{حَدَّثَنَا دَاوُدُ بْنُ سُلَيْمَانَ الْعَسْكَرِيُّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا سَعِيدُ بْنُ مُحَمَّدٍ الثَّقَفِيُّ، عَنْ مُوسَى الْجُهَنِيِّ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ عَطِيَّةَ بْنِ عَامِرٍ الْجُهَنِيِّ، قَالَ سَمِعْتُ سَلْمَانَ، وَأُكْرِهَ، عَلَى طَعَامٍ يَأْكُلُهُ فَقَالَ حَسْبِي إِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِنَّ أَكْثَرَ النَّاسِ شِبَعًا فِي الدُّنْيَا أَطْوَلُهُمْ جُوعًا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{3351}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Atiyyah bin ‘Amir Al-Juhani said:“I heard Salman, when he was forced to eat food, say: ‘It is sufficient for me that I heard the Messenger of Allah (ﷺ) say: The people who most eat their fill in this world will be the most hungry on the Day of Resurrection.’”}}
\hadithdefcmd{ibnmajah}{3352}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَسُوَيْدُ بْنُ سَعِيدٍ، وَيَحْيَى بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، قَالُوا حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، حَدَّثَنَا يُوسُفُ بْنُ أَبِي كَثِيرٍ، عَنْ نُوحِ بْنِ ذَكْوَانَ، عَنِ الْحَسَنِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ مِنَ السَّرَفِ أَنْ تَأْكُلَ كُلَّ مَا اشْتَهَيْتَ ‏"‏ ‏.‏\hadithno{3352}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“It is extravagance to eat everything you want.”}}
\hadithdefcmd{ibnmajah}{3353}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنِ يُوسُفَ الْفِرْيَابِيُّ، حَدَّثَنَا وَسَّاجُ بْنُ عُقْبَةَ بْنِ وَسَّاجٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُحَمَّدٍ الْمُوَقَّرِيُّ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَ النَّبِيُّ ـ صلى الله عليه وسلم ـ الْبَيْتَ فَرَأَى كِسْرَةً مُلْقَاةً فَأَخَذَهَا فَمَسَحَهَا ثُمَّ أَكَلَهَا وَقَالَ ‏ "‏ يَا عَائِشَةُ أَكْرِمِي كَرِيمَكِ فَإِنَّهَا مَا نَفَرَتْ عَنْ قَوْمٍ قَطُّ فَعَادَتْ إِلَيْهِمْ ‏"‏ ‏.‏\hadithno{3353}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) entered the house and saw a piece of bread that had been thrown (on the floor). He picked it up, wiped it and ate it, and said: ‘O ‘Aishah, show honor to the precious (i.e., food), for is the blessing of food departs from people, it never comes back.’”}}
\hadithdefcmd{ibnmajah}{3354}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا هُرَيْمٌ، عَنْ لَيْثٍ، عَنْ كَعْبٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْجُوعِ فَإِنَّهُ بِئْسَ الضَّجِيعُ وَأَعُوذُ بِكَ مِنَ الْخِيَانَةِ فَإِنَّهَا بِئْسَتِ الْبِطَانَةُ ‏"‏ ‏.‏\hadithno{3354}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) used to say: ‘Allahumma inni a’udhu bika minal-ju’, fa innahu bi’sad- daji’, wa a’udhu bika minal-khiyanah, fa innaha bi’satil-bitanah (O Allah, I seek refuge with You from hunger, for it is a bad companion, and I seek refuge with You from treachery, for it is a bad thing to hide in one’s heart).’”}}
\hadithdefcmd{ibnmajah}{3355}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الرَّقِّيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ عَبْدِ السَّلاَمِ بْنِ عَبْدِ اللَّهِ بْنِ بَابَاهْ الْمَخْزُومِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَيْمُونٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَدَعُوا الْعَشَاءَ وَلَوْ بِكَفٍّ مِنْ تَمْرٍ فَإِنَّ تَرْكَهُ يُهْرِمُ ‏"‏ ‏.‏\hadithno{3355}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that the Messenger of Allah (ﷺ) said:“Do not leave dinner, even if it is only a handful of dates, because abandoning it makes one weak.”}}
\hadithdefcmd{ibnmajah}{3356}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا كَثِيرُ بْنُ سُلَيْمٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْخَيْرُ أَسْرَعُ إِلَى الْبَيْتِ الَّذِي يُغْشَى مِنَ الشَّفْرَةِ إِلَى سَنَامِ الْبَعِيرِ ‏"‏ ‏.‏\hadithno{3356}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{(It was narrated from Anas bin Malik that the Messenger of Allah 9saw) said:“Goodness comes more quickly to a house where there are frequent guests than a knife to camel’s hump.”}}
\hadithdefcmd{ibnmajah}{3357}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا الْمُحَارِبِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ نَهْشَلٍ، عَنِ الضَّحَّاكِ بْنِ مُزَاحِمٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْخَيْرُ أَسْرَعُ إِلَى الْبَيْتِ الَّذِي يُؤْكَلُ فِيهِ مِنَ الشَّفْرَةِ إِلَى سَنَامِ الْبَعِيرِ ‏"‏ ‏.‏\hadithno{3357}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“Goodness comes more quickly to a house where food is eaten than a knife to a camel’s hump.”}}
\hadithdefcmd{ibnmajah}{3358}{حَدَّثَنَا عَلِيُّ بْنُ مَيْمُونٍ الرَّقِّيُّ، حَدَّثَنَا عُثْمَانُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ عَلِيِّ بْنِ عُرْوَةَ، عَنْ عَبْدِ الْمَلِكِ، عَنْ عَطَاءٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ مِنَ السُّنَّةِ أَنْ يَخْرُجَ الرَّجُلُ مَعَ ضَيْفِهِ إِلَى بَابِ الدَّارِ ‏"‏ ‏.‏\hadithno{3358}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“It is the Sunnah for a man to go out with his guest to the door of the house.’”}}
\hadithdefcmd{ibnmajah}{3359}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عَلِيٍّ، قَالَ صَنَعْتُ طَعَامًا فَدَعَوْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَجَاءَ فَرَأَى فِي الْبَيْتِ تَصَاوِيرَ فَرَجَعَ ‏.‏\hadithno{3359}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Ali said:“I made some food and called the Messenger of Allah (ﷺ) (to come and eat). He came and saw some images in the house, so he went back.”}}
\hadithdefcmd{ibnmajah}{3360}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ الْجَزَرِيُّ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، حَدَّثَنَا سَعِيدُ بْنُ جُمْهَانَ، حَدَّثَنَا سَفِينَةُ أَبُو عَبْدِ الرَّحْمَنِ، أَنَّ رَجُلاً، أَضَافَ عَلِيَّ بْنَ أَبِي طَالِبٍ فَصَنَعَ لَهُ طَعَامًا فَقَالَتْ فَاطِمَةُ لَوْ دَعَوْنَا النَّبِيَّ ـ صلى الله عليه وسلم ـ فَأَكَلَ مَعَنَا ‏.‏ فَدَعَوْهُ فَجَاءَ فَوَضَعَ يَدَهُ عَلَى عِضَادَتَىِ الْبَابِ فَرَأَى قِرَامًا فِي نَاحِيَةِ الْبَيْتِ فَرَجَعَ فَقَالَتْ فَاطِمَةُ لِعَلِيٍّ الْحَقْ فَقُلْ لَهُ مَا رَجَعَكَ يَا رَسُولَ اللَّهِ قَالَ ‏ "‏ إِنَّهُ لَيْسَ لِي أَنْ أَدْخُلَ بَيْتًا مُزَوَّقًا ‏"‏ ‏.‏\hadithno{3360}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Safinah, Abu ‘Abdur-Rahman, narrated that a man visited ‘Ali bin Abu Talib and he made some food for him.* Fatimah said:“Why don’t we invite the Prophet (ﷺ) to eat with us?” So they invited him and he came. He put his hand on the doorpost of the house and saw a thin curtain in the corner of the house, so he went back. Fatimah said to ‘Ali: “Go and catch up with him, and ask him: ‘What made you go back, O Messenger of Allah?” He said: “I do not enter a well-decorated house.”}}
\hadithdefcmd{ibnmajah}{3361}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا يَحْيَى بْنُ عَبْدِ الرَّحْمَنِ الأَرْحَبِيُّ، حَدَّثَنَا يُونُسُ بْنُ أَبِي الْيَعْفُورِ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ دَخَلَ عَلَيْهِ عُمَرُ وَهُوَ عَلَى مَائِدَتِهِ فَأَوْسَعَ لَهُ عَنْ صَدْرِ الْمَجْلِسِ فَقَالَ بِسْمِ اللَّهِ ‏.‏ ثُمَّ ضَرَبَ بِيَدِهِ فَلَقِمَ لُقْمَةً ثُمَّ ثَنَّى بِأُخْرَى ثُمَّ قَالَ إِنِّي لأَجِدُ طَعْمَ دَسَمٍ مَا هُوَ بِدَسَمِ اللَّحْمِ ‏.‏ فَقَالَ عَبْدُ اللَّهِ يَا أَمِيرَ الْمُؤْمِنِينَ إِنِّي خَرَجْتُ إِلَى السُّوقِ أَطْلُبُ السَّمِينَ لأَشْتَرِيَهُ فَوَجَدْتُهُ غَالِيًا فَاشْتَرَيْتُ بِدِرْهَمٍ مِنَ الْمَهْزُولِ وَحَمَلْتُ عَلَيْهِ بِدِرْهَمٍ سَمْنًا فَأَرَدْتُ أَنْ يَتَرَدَّدَ عِيَالِي عَظْمًا عَظْمًا ‏.‏ فَقَالَ عُمَرُ مَا اجْتَمَعَا عِنْدَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَطُّ إِلاَّ أَكَلَ أَحَدَهُمَا وَتَصَدَّقَ بِالآخَرِ ‏.‏ قَالَ عَبْدُ اللَّهِ خُذْ يَا أَمِيرَ الْمُؤْمِنِينَ فَلَنْ يَجْتَمِعَا عِنْدِي إِلاَّ فَعَلْتُ ذَلِكَ ‏.‏ قَالَ مَا كُنْتُ لأَفْعَلَ ‏.‏\hadithno{3361}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn ‘Umar said that ‘Umar entered upon him when he was eating, and he made room for him in the middle of the gathering. He said:Bismillah, then he took a morsel and ate it, then a second. Then he said: “I notice some fat in the food but it is not the fat of the meat.” ‘Abdullah said: “O Commander of the Believers! I went out to the marketplace looking for some fatty meat (bones with plenty of meat on them) to buy, but it was expensive, so I bought some lean meat (bones with not much meat on them) for a Dirham, and added a Dirham’s worth of ghee. I wanted my family to go through it bone by bone.” ‘Umar said: “The Messenger of Allah (ﷺ) never had these two things together; he would eat one and give the other in charity.”}}
\hadithdefcmd{ibnmajah}{3362}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، حَدَّثَنَا أَبُو عَامِرٍ الْخَزَّازُ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا عَمِلْتَ مَرَقَةً فَأَكْثِرْ مَاءَهَا وَاغْتَرِفْ لِجِيرَانِكَ مِنْهَا ‏"‏ ‏.‏\hadithno{3362}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Dharr that the Prophet (ﷺ) said:“When you make broth, add more water and give some to your neighbor.”}}
\hadithdefcmd{ibnmajah}{3363}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ الْغَطَفَانِيِّ، عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ الْيَعْمُرِيِّ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَامَ يَوْمَ الْجُمُعَةِ خَطِيبًا فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ يَا أَيُّهَا النَّاسُ إِنَّكُمْ تَأْكُلُونَ شَجَرَتَيْنِ لاَ أُرَاهُمَا إِلاَّ خَبِيثَتَيْنِ هَذَا الثُّومُ وَهَذَا الْبَصَلُ وَلَقَدْ كُنْتُ أَرَى الرَّجُلَ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ يُوجَدُ رِيحُهُ مِنْهُ فَيُؤْخَذُ بِيَدِهِ حَتَّى يُخْرَجَ بِهِ إِلَى الْبَقِيعِ فَمَنْ كَانَ آكِلَهُمَا لاَ بُدَّ فَلْيُمِتْهُمَا طَبْخًا ‏.‏\hadithno{3363}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ma’dan bin Abu Talhah Al-Ya’muri that ‘Umar bin Khattab stood up one Friday delivering a sermon. He praised and glorified Allah, then he said:“O people, you eat two plants which I do not regard as anything but offensive: This garlic and these onions. At the time of the Messenger of Allah (ﷺ), I would see a man, if the smell (of these vegetables) was found on him, being taken by the hand and led out to Baqi’ (graveyard). Whoever must eat them, let him cook them to death.”}}
\hadithdefcmd{ibnmajah}{3364}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، عَنْ أَبِيهِ، عَنْ أُمِّ أَيُّوبَ، قَالَتْ صَنَعْتُ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ طَعَامًا فِيهِ مِنْ بَعْضِ الْبُقُولِ فَلَمْ يَأْكُلْ وَقَالَ ‏ "‏ إِنِّي أَكْرَهُ أَنْ أُوذِيَ صَاحِبِي ‏"‏ ‏.‏\hadithno{3364}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Umm Ayyub said:“I made some food for the Prophet (ﷺ) in which there were some vegetables. He did not eat it, and he said: ‘I do not like to annoy my companion.’”}}
\hadithdefcmd{ibnmajah}{3365}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَنْبَأَنَا أَبُو شُرَيْحٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ نِمْرَانَ الْحَجْرِيِّ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ نَفَرًا، أَتَوُا النَّبِيَّ ـ صلى الله عليه وسلم ـ فَوَجَدَ مِنْهُمْ رِيحَ الْكُرَّاثِ فَقَالَ ‏ "‏ أَلَمْ أَكُنْ نَهَيْتُكُمْ عَنْ أَكْلِ هَذِهِ الشَّجَرَةِ إِنَّ الْمَلاَئِكَةَ تَتَأَذَّى مِمَّا يَتَأَذَّى مِنْهُ الإِنْسَانُ ‏"‏ ‏.‏\hadithno{3365}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir that a group of people came to the Prophet (ﷺ) and he noticed the smell of leeks coming from them. He said:“Did I not forbid you to eat these vegetables? For the angels are offended by that which offends people.”}}
\hadithdefcmd{ibnmajah}{3366}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي ابْنُ لَهِيعَةَ، عَنْ عُثْمَانَ بْنِ نُعَيْمٍ، عَنِ الْمُغِيرَةِ بْنِ نَهِيكٍ، عَنْ دُخَيْنٍ الْحَجْرِيِّ، أَنَّهُ سَمِعَ عُقْبَةَ بْنَ عَامِرٍ الْجُهَنِيَّ، يَقُولُ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ لأَصْحَابِهِ ‏"‏ لاَ تَأْكُلُوا الْبَصَلَ ‏"‏ ‏.‏ ثُمَّ قَالَ كَلِمَةً خَفِيَّةً ‏"‏ النِّيءَ ‏"‏ ‏.‏\hadithno{3366}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Uqbah bin ‘Amir Al-Juhani said:“The Messenger of Allah (ﷺ) said to his Companions: ‘Do not eat onions,’ then he said in a low voice: ‘Raw.’”}}
\hadithdefcmd{ibnmajah}{3367}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى السُّدِّيُّ، حَدَّثَنَا سَيْفُ بْنُ هَارُونَ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ سَلْمَانَ الْفَارِسِيِّ، قَالَ سُئِلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ السَّمْنِ وَالْجُبْنِ وَالْفِرَاءِ قَالَ ‏ "‏ الْحَلاَلُ مَا أَحَلَّ اللَّهُ فِي كِتَابِهِ وَالْحَرَامُ مَا حَرَّمَ اللَّهُ فِي كِتَابِهِ وَمَا سَكَتَ عَنْهُ فَهُوَ مِمَّا عَفَا عَنْهُ ‏"‏ ‏.‏\hadithno{3367}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Salman Al-Farisi said:“The Messenger of Allah (ﷺ) was asked about ghee, cheese and wild donkeys. He said: ‘What is lawful is that which Allah has permitted, in His Book and what is unlawful is that which Allah has forbidden in His Book. What He remained silent about is what is pardoned.’”}}
\hadithdefcmd{ibnmajah}{3368}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عِرْقٍ، عَنْ أَبِيهِ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ أُهْدِيَ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ عِنَبٌ مِنَ الطَّائِفِ فَدَعَانِي فَقَالَ ‏"‏ خُذْ هَذَا الْعُنْقُودَ فَأَبْلِغْهُ أُمَّكَ ‏"‏ ‏.‏ فَأَكَلْتُهُ قَبْلَ أَنْ أُبْلِغَهُ إِيَّاهَا فَلَمَّا كَانَ بَعْدَ لَيَالٍ قَالَ لِي ‏"‏ مَا فَعَلَ الْعُنْقُودُ هَلْ أَبْلَغْتَهُ أُمَّكَ ‏"‏ ‏.‏ قُلْتُ لاَ ‏.‏ قَالَ فَسَمَّانِي غُدَرَ ‏.‏\hadithno{3368}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Nu’man bin Bashir said:“The Prophet (ﷺ) was given a gift of some grapes from Ta’if. He called me and said: ‘Take this bunch of grapes and give it to your mother.’ But I ate it before I gave it to her. A few night later he said to me: ‘What happened to the bunch of grapes? Did you give it to your mother?’ I said: ‘No, So he called me treacherous.’”}}
\hadithdefcmd{ibnmajah}{3369}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُحَمَّدٍ الطَّلْحِيُّ، حَدَّثَنَا نُقَيْبُ بْنُ حَاجِبٍ، عَنْ أَبِي سَعِيدٍ، عَنْ عَبْدِ الْمَلِكِ الزُّبَيْرِيِّ، عَنْ طَلْحَةَ، قَالَ دَخَلْتُ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ وَبِيَدِهِ سَفَرْجَلَةٌ فَقَالَ ‏ "‏ دُونَكَهَا يَا طَلْحَةُ فَإِنَّهَا تُجِمُّ الْفُؤَادَ ‏"‏ ‏.‏\hadithno{3369}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Talhah said:”I entered upon the Prophet (ﷺ) and in his hand was some quince. He said: ‘Take it, O Talhah, for it soothes the heart.’”}}
\hadithdefcmd{ibnmajah}{3370}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا كَثِيرُ بْنُ هِشَامٍ، حَدَّثَنَا جَعْفَرُ بْنُ بُرْقَانَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يَأْكُلَ الرَّجُلُ وَهُوَ مُنْبَطِحٌ عَلَى وَجْهِهِ ‏.‏\hadithno{3370}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Salim that his father said:“The Messenger of Allah (ﷺ) forbade a man from eating while lying down on his face.”}}
